@@ -19,7 +19,7 @@ use Types::Standard qw/Str Int Bool HashRef/;
 use Type::Utils;
 use Module::Pluggable require => 1, search_path => ['Group::Git::Cmd', 'Group::Git::Taggers'];
 
-our $VERSION = version->new('0.5.9');
+our $VERSION = version->new('0.5.10');
 our $AUTOLOAD;
 
 has conf => (
@@ -73,6 +73,10 @@ sub _repos {
     my ($self) = @_;
     my %repos;
     my @files = path('.')->children;
+    my %tags;
+    for my $tag ( keys %{ $self->conf->{tags} } ) {
+        $tags{$tag} = { map { $_ => 1 } @{ $self->conf->{tags}{$tag} } };
+    }
 
     while ( my $file = shift @files ) {
         next unless -d $file;
@@ -97,7 +101,19 @@ sub _repos {
         $repos{$file} = Group::Git::Repo->new(
             name => $file,
             git  => $url,
+            tags => {
+                map {m{/[.](.*?)[.]tag$}; $1 => 1}
+                glob "$file/.*.tag"
+            },
         );
+
+        for my $tag (keys %{ $repos{$file}->tags } ) {
+            $tags{$tag}{$file} = 1;
+        }
+    }
+
+    for my $tag (keys %tags) {
+        $self->conf->{tags}{$tag} = [ sort keys %{ $tags{$tag} } ];
     }
 
     return \%repos;
@@ -146,7 +162,7 @@ Group::Git - Base module for group of git repository operations.
 
 =head1 VERSION
 
-This documentation refers to Group::Git version 0.5.9.
+This documentation refers to Group::Git version 0.5.10.
 
 =head1 SYNOPSIS
 
