@@ -10,10 +10,10 @@ use Moo;
 use strict;
 use warnings;
 use version;
-use Types::Standard qw/Str/;
+use Types::Standard qw/Str HashRef/;
 use Type::Utils;
 
-our $VERSION = version->new('0.5.9');
+our $VERSION = version->new('0.5.10');
 
 extends 'Group::Git';
 
@@ -29,6 +29,12 @@ has git => (
     is  => 'rw',
     isa => Str,
 );
+has tags => (
+    is      => 'rw',
+    isa     => HashRef,
+    default => sub {{}},
+);
+
 has mech => (
     is      => 'rw',
     lazy    => 1,
@@ -64,7 +70,7 @@ Group::Git::Repo - Git repository details object.
 
 =head1 VERSION
 
-This documentation refers to Group::Git::Repo version 0.5.9.
+This documentation refers to Group::Git::Repo version 0.5.10.
 
 
 =head1 SYNOPSIS
